@@ -1,8 +1,8 @@
-"""Module with graph embedding models based on PyKeen."""
+"""Module with graph embedding models based on PyKEEN."""
 from embiggen.utils.abstract_models import build_init, AbstractEmbeddingModel
 
 build_init(
     module_library_names=["torch", "pykeen"],
-    formatted_library_name="PyKeen",
+    formatted_library_name="PyKEEN",
     expected_parent_class=AbstractEmbeddingModel
 )
\ No newline at end of file
